<?php
/*
* ---------------------------------------------------------
* This file contains function stubs for the following XAPI-J extension:
*
*   QueryExtension
*
* which is referenced in the php.ini file with the following line:
*
*   extension = zero.data.php.QueryExtension
*
* This file allows the extension functions to be found by PDT code assist.
* It should not be used in include or require statements.
* ---------------------------------------------------------
*/

/**
 * Enters transaction mode with the given Manager. This mode is exited by
 calling either dataCommitTransaction or dataRollbackTransaction.
 * @return boolean
 * @param handle Manager
 */
function dataBeginTransaction($handle) {
}

/**
 * Returns the contents of the Blob resource as a string.
 * @return string
 * @param handle Blob
 * @param position int
 * @param length int
 */
function dataBlobGetBytes($handle, $position, $length) {
}

/**
 * Returns the length of the Blob resource data.
 * @return double
 * @param handle Blob
 */
function dataBlobLength($handle) {
}

/**
 * Sets the byte contents of the Blob resource.
 * @return int
 * @param handle Blob
 * @param position int
 * @param bytes string
 * @param offset int
 * @param length in
 */
function dataBlobSetBytes($handle, $position, $bytes, $offset, $length) {
}

/**
 * Returns the contents of the Clob resource as a string.
 * @return string
 * @param handle Clob
 */
function dataClobGetString($handle) {
}

/**
 * Returns the length of the Clob resource data.
 * @return double
 * @param handle Clob
 */
function dataClobLength($handle) {
}

/**
 * Commits the current transaction and then exits transaction mode. The
 caller should have called dataBeginTransaction before calling this API.
 * @return boolean
 * @param handle Manager
 */
function dataCommitTransaction($handle) {
}

/**
 * Ends the current transaction
 */
function dataEndTransaction() {
}

/**
 * Executes any SQL statement. SELECT operations are handled by queryArray,
 while all other operations are handled by update. Returns the following
 types:
 
 <ul>
 <li>SELECT - array of associative arrays similar to dataQueryArray result
 </li> <li>others - an integer indicating the number of affected rows.
 </li>
 </ul>
 
 When the Manager handle or the SQL statement are missing, the return
 value is always null. When an error occurs during an update operation,
 the return value is false.
 * @return mixed
 * @param handle Manager
 * @param sql string
 * @param params array
 */
function dataExec($handle, $sql, $params) {
}

/**
 * An optimized form of the exec API which behaves like queryFirst for
 SELECT statements and updateMany for other statements.
 
 Returns the following types:
 
 <ul>
 <li>SELECT - associative array</li> <li>others - integer array</li>
 </ul>
 
 When the Manager handle or the SQL statement are missing, the return
 value is always null. When an error occurs during an update operation,
 the return value is false.
 * @return mixed
 * @param handle Manager
 * @param sql string
 * @param params array
 */
function dataExecOpt($handle, $sql, $params) {
}

/**
 * Executes UPDATE and INSERT statements and returns generated column
 values. The values of the generated keys are returned as strings that can
 be coerced to another type if needed.
 * @return mixed
 * @param handle Manager
 * @param sql string
 * @param columnNames array
 * @param params array
 */
function dataInsert($handle, $sql, $columnNames, $params) {
}

/**
 * Returns true if in transaction, false otherwise
 */
function dataIsInTransaction() {
}

/**
 * Validates if manager has configuration that can connect to a database.
 * @return true
 * @param handle Manager
 */
function dataIsValid($handle) {
}

/**
 * Returns true if there is a next item.
 * @return boolean
 * @param handle Iterator
 */
function dataIteratorHasNext($handle) {
}

/**
 * Returns the next item.
 * @return mixed
 * @param handle Iterator
 */
function dataIteratorNext($handle) {
}

/**
 * Removes the current item.
 * @param handle Iterator
 */
function dataIteratorRemove($handle) {
}

/**
 * Returns information about the last error. If an error already occurred,
 the return value will be an associative array with the given keys.
 
 <ul>
 <li>&quot;type&quot; - one of WARNING, SEVERE, FATAL</li>
 <li>&quot;functionName&quot; - the name of the function that triggered
 the error</li>
 <li>&quot;message&quot; - error message</li>
 </ul>
 
 <p>
 Note that the last error field is not reset after a successful function
 call. So this function is most useful when an error occurs as indicated
 by the failing function itself.
 * @return mixed
 */
function dataLastError() {
}

/**
 * Creates a new Manager from a DataSource. The DataSource is indicated in
 one of two ways. The first way is to pass a resource that is returned
 from the dataSource API. The second way is to pass a string key that
 corresponds to a set of database parameters in the zero.config file.
 * @return Manager
 * @param handle mixed
 */
function dataManager($handle) {
}

/**
 * Creates an instance of ResultHandler for use with the dataQuery API.
 * @return resource
 * @param name string
 */
function dataNewResultHandler($name) {
}

/**
 * Executes a SQL query and uses the result handler to create the return
 value. The result handler can have one of two forms which are listed
 below.
 
 <ol>
 <li>PHP callback function - indicated by passing the function name</li>
 <li>PHP ResultHandler resource</li>
 </ol>
 
 <p>
 The callback function should have the following prototype. The argument
 is a ResultSet resource, which can be accessed using the dataResultSet
 APIs. The value returned from this callback function will then be
 returned to the caller of dataQuery.
 
 <p>
 <code>function callback($resultSet)</code>
 * @return mixed
 * @param handle Manager
 * @param sql string
 * @param resultHandler mixed
 * @param params array
 */
function dataQuery($handle, $sql, $resultHandler, $params) {
}

/**
 * Executes a SQL query and returns an array of results where each element
 represents a single row. The rows themselves are associative arrays.
 * @return array
 * @param handle Manager
 * @param sql string
 * @param params array
 */
function dataQueryArray($handle, $sql, $params) {
}

/**
 * Executes a SQL query and uses the factory callback function to create the
 return value. The callback function will be called once per row. The
 result of each callback will be placed in an array and returned to the
 caller of this API.
 
 <p>
 The callback function should have the following prototype. The argument
 is a ResultSet resource, which can be accessed using the dataResultSet
 APIs. The value returned from this callback function will then be
 returned to the caller of dataQueryArrayByFactory.
 
 <p>
 <code>function callback($resultSet)</code>
 * @return array
 * @param handle Manager
 * @param sql string
 * @param factoryCallback callback
 * @param params array
 */
function dataQueryArrayByFactory($handle, $sql, $factoryCallback, $params) {
}

/**
 * Executes a SQL query and returns the first result row as an associative
 array.
 * @return array
 * @param handle Manager
 * @param sql string
 * @param params array
 */
function dataQueryFirst($handle, $sql, $params) {
}

/**
 * Executes a SQL query and uses the factory callback function to create the
 return value. The result of the query will contain at most one row. The
 callback function will be called exactly once.
 
 <p>
 The callback function should have the following prototype. The argument
 is a ResultSet resource, which can be accessed using the dataResultSet
 APIs. The value returned from this callback function will then be
 returned to the caller of dataQueryFirstByFactory.
 
 <p>
 <code>function callback($resultSet)</code>
 * @return mixed
 * @param handle Manager
 * @param sql string
 * @param factoryCallback callback
 * @param params array
 */
function dataQueryFirstByFactory($handle, $sql, $factoryCallback, $params) {
}

/**
 * Executes a SQL query and returns an Iterator resource. The Iterator can
 be manipulated using the dataIterator APIs. Each iterated element
 represents a single row from the query result.
 * @return Iterator
 * @param handle Manager
 * @param sql string
 * @param params array
 */
function dataQueryIterator($handle, $sql, $params) {
}

/**
 * Executes a SQL query and uses the factory callback function to create the
 return value. The callback function will be called once per row. The
 result of each callback will be accessible via the Iterator resource
 which is returned to the caller of this API.
 
 <p>
 The callback function should have the following prototype. The argument
 is a ResultSet resource, which can be accessed using the dataResultSet
 APIs. The value returned from this callback function will then be
 returned to the caller of dataQueryIteratorByFactory.
 
 <p>
 <code>function callback($resultSet)</code>
 * @return Iterator
 * @param handle Manager
 * @param sql string
 * @param factoryCallback callback
 * @param params array
 */
function dataQueryIteratorByFactory($handle, $sql, $factoryCallback, $params) {
}

/**
 * Executes a SQL query and returns a ResultSet resource which can be
 accessed using the dataResultSet APIs.
 * @return ResultSet
 * @param handle Manager
 * @param sql string
 * @param params array
 */
function dataQueryResults($handle, $sql, $params) {
}

/**
 * Sets the current row index relative to either the beginning or the end of
 the ResultSet.
 * @return boolean
 * @param handle ResultSet
 * @param row int
 */
function dataResultSetAbsolute($handle, $row) {
}

/**
 * Closes the ResultSet resource.
 * @return boolean
 * @param handle ResultSet
 */
function dataResultSetClose($handle) {
}

/**
 * Returns the number of columns in the ResultSet resource.
 * @return int
 * @param handle ResultSet
 */
function dataResultSetGetColumnCount($handle) {
}

/**
 * Returns the name of the given column.
 * @return string
 * @param handle ResultSet
 * @param index int
 */
function dataResultSetGetColumnName($handle, $index) {
}

/**
 * Returns the value of the given column.
 * @return mixed
 * @param handle ResultSet
 * @param column mixed
 */
function dataResultSetGetObject($handle, $column) {
}

/**
 * Returns the index of the current row. The index of the first row is 1.
 * @return int
 * @param handle ResultSet
 */
function dataResultSetGetRow($handle) {
}

/**
 * Move the internal position of the ResultSet resource to the next row.
 * @return boolean
 * @param handle ResultSet
 */
function dataResultSetNext($handle) {
}

/**
 * Move the internal position of the ResultSet resource to the previous row.
 * @return boolean
 * @param handle ResultSet
 */
function dataResultSetPrevious($handle) {
}

/**
 * Rollback the current transaction and then exits transaction mode. The
 caller should have called dataBeginTransaction before calling this API.
 * @return boolean
 * @param handle Manager
 */
function dataRollbackTransaction($handle) {
}

/**
 * Creates and returns a DataSource of the given type. The type argument has
 three possible meanings which are tested in the order shown. As soon as
 one of the mechanisms is successful at creating a DataSource, the
 function returns it.
 
 <ol>
 <li>The type name has been previously registered with an
 IDataSourceProvider instance. See DataSourceFactory.registerProvider()
 for details.</li> <li>The type name is the fully qualified class name of
 a DataSource implementor. The class will be instantiated with the default
 constructor, and the params will be set on the created DataSource object.
 Note that parameter keys are expected to map one-to-one with setter
 methods on the object.</li> <li>The type name, when appended to the
 string "zero.data.php.datasource.", forms a fully qualified class name of
 an IDataSourceProvider implementor. The IDataSourceProvider will be
 instantiated and registered with the type name.</li>
 </ol>
 * @return resource
 * @param type string
 * @param params array
 */
function dataSource($type, $params) {
}

/**
 * Returns the string argument as a string data resource. This kind of
 resource is used in situations where a BLOB is expected by the SQL
 engine.
 * @return resource
 * @param string string
 */
function dataStringAsByteArray($string) {
}

/**
 * Executes the given callback as a database transaction. If any errors
 occur, the entire transaction will be rolled back.
 
 <p>
 The callback function should have the following prototype. The $userData
 argument may be omitted if not being used.
 
 <p>
 <code>function callback($manager, $userData)</code>
 
 <p>
 Under normal circumstances, the callback is not required to return a
 value. However, there are two ways for the callback to explicitly fail
 the transaction. The callback can either throw an exception, or return
 false. For example:
 
 <p>
 <code>
 function callback($manager, $userData) {<br/>
     // ... query code ...<br/>
     throw new Exception("message");<br/>
 }<br/>
 </code>
 
 <p>
 <code>
 function callback($manager, $userData) {<br/>
     // ... query code ...<br/>
     return false;<br/>
 }<br/>
 </code>
 * @return boolean
 * @param handle Manager
 * @param callback callback
 * @param userData mixed
 */
function dataTransaction($handle, $callback, $userData) {
}

/**
 * Executes a SQL update.
 * @return mixed
 * @param handle Manager
 * @param sql string
 * @param params array
 */
function dataUpdate($handle, $sql, $params) {
}

/**
 * Executes a batch SQL update. The SQL statement is executed once for each
 associative array nested in the parameters array.
 * @return mixed
 * @param handle Manager
 * @param sql string
 * @param params array
 */
function dataUpdateMany($handle, $sql, $params) {
}
?>
